@@ -354,6 +354,14 @@ class AnyTestItem(pytest.Item):
             self.name
         )
 
+        import debugpy
+        # 5678 is the default attach port in the VS Code debug configurations. Unless a host and port are specified, host defaults to 127.0.0.1
+        debugpy.listen(5678)
+        print('Waiting for debugger attach')
+        debugpy.wait_for_client()
+        debugpy.breakpoint()
+        print('break on this line')
+
         with change_dir(tmpdir):
             self.app = AnyPyProcess(**self.app_opts)
             if ON_WINDOWS:
@@ -427,7 +435,7 @@ class AnyTestItem(pytest.Item):
 
         target_folder = Path(target_folder)
         src_folder = Path(src_folder)
-        src_log = Path(result["task_logfile"])
+        src_log = src_folder / Path(result["task_logfile"]).name
 
         if target_folder.exists():
             shutil.rmtree(target_folder)
