@@ -76,7 +76,7 @@ def case_preserving_replace(string, old, new):
 
 @functools.lru_cache(maxsize=None)
 def winepath(path, opts=None):
-    """ " Wrapper for the winepath commandline tool"""
+    """Wrapper for the winepath commandline tool"""
     if not opts:
         opts = ["-u"]
     if isinstance(opts, str):
@@ -92,13 +92,27 @@ def winepath(path, opts=None):
 
 def anybodycon_version(anybodyconpath=None):
     """Return the AnyBodyCon version."""
-    anybodyconpath = anybodyconpath or get_anybodycon_path()
-    if anybodyconpath is None:
+    if not anybodyconpath:
+        anybodyconpath = get_anybodycon_path()
+    if anybodyconpath:
+        anybodyconpath = str(Path(anybodyconpath).absolute())
+    return _anybodycon_version(anybodyconpath)
+
+
+@functools.lru_cache(maxsize=None)
+def _anybodycon_version(anybodyconpath):
+    """Return the AnyBodyCon version."""
+    if not anybodyconpath:
         return "0.0.0"
     cmd = [anybodyconpath, "-ni"]
     if not ON_WINDOWS:
         cmd.insert(0, "wine")
-    out = subprocess.run(cmd, universal_newlines=True, stdout=subprocess.PIPE).stdout
+    try:
+        out = subprocess.run(
+            cmd, universal_newlines=True, stdout=subprocess.PIPE
+        ).stdout
+    except (subprocess.CalledProcessError, FileNotFoundError):
+        out = ""
     m = ANYBODYCON_VERSION_RE.search(out)
     if m:
         return m.groupdict()["version"]
@@ -130,7 +144,7 @@ def wraptext(elem, initial_indent="", subsequent_indent=None):
     )
 
 
-def amm_xml_version(fpath):
+def ammr_xml_version(fpath):
     try:
         tree = xml.etree.ElementTree.parse(fpath)
         version = tree.getroot()
@@ -173,7 +187,7 @@ def get_ammr_version(folder=None):
     if any_version_file in files:
         return ammr_any_version(os.path.join(folder, any_version_file))
     elif xml_version_file in files:
-        return amm_xml_version(os.path.join(folder, xml_version_file))
+        return ammr_xml_version(os.path.join(folder, xml_version_file))
     else:
         return ""
 
@@ -570,17 +584,21 @@ class AnyPyProcessOutput(collections.OrderedDict):
             raise KeyError(msg) from None
 
     def _repr_gen(self, prefix):
-        items = self.items()
-        if not items:
+
+        kv_values = {
+            k: v
+            for k, v in self.items()
+            if not k.startswith("task_") or self._task_info_in_repr
+        }
+
+        if not kv_values:
             yield prefix + "{}"
             return
 
         indent = prefix + "{"
-        for i, (key, val) in enumerate(items):
-            if not self._task_info_in_repr and key.startswith("task_"):
-                continue
+        for i, (key, val) in enumerate(kv_values.items()):
 
-            if i == len(self.keys()) - 1:
+            if i == len(kv_values) - 1:
                 end = "}"
             else:
                 end = ","
